@@ -331,7 +331,7 @@ class EvaluationAttribute(TaurusAttribute):
         refobj = Attribute(ref)
         if refobj not in self._references:
             evaluator = self.getParentObj()
-            v = refobj.read().rvalue
+            v = refobj.read(cache=False).rvalue
             # add its rvalue to the evaluator symbols
             evaluator.addSafe({self.getId(refobj): v})
             # add the object to the reference list
