@@ -35,10 +35,9 @@ import PyTango
 import numpy
 from functools import partial
 
-from taurus import Manager
+from taurus import Manager, tauruscustomsettings
 from taurus.core.units import Quantity, UR
 
-from taurus import tauruscustomsettings
 from taurus.core.taurusattribute import TaurusAttribute
 from taurus.core.taurusbasetypes import (
     TaurusEventType,
@@ -55,11 +54,13 @@ from taurus.core.util.log import (
     taurus4_deprecation,
     deprecation_decorator,
 )
+from taurus.taurusstatecontroller import application, ApplicationStates
 
 from taurus.core.tango.enums import (
     EVENT_TO_POLLING_EXCEPTIONS,
     FROM_TANGO_TO_NUMPY_TYPE,
     DevState,
+    TIMEOUT_EXCEPTION,
 )
 
 from .util.tango_taurus import (
@@ -72,7 +73,6 @@ from .util.tango_taurus import (
     data_type_from_tango,
 )
 
-
 __docformat__ = "restructuredtext"
 
 
@@ -109,7 +109,7 @@ class TangoAttrValue(TaurusAttrValue):
 
         numerical = PyTango.is_numerical_type(
             self._attrRef._tango_data_type, inc_array=True
-        )
+        ) or (self._attrRef._tango_data_type == PyTango.DevEnum)
 
         if p.has_failed:
             self.error = PyTango.DevFailed(*p.get_err_stack())
@@ -300,6 +300,7 @@ class TangoAttribute(TaurusAttribute):
         # the last attribute error and its timestamp
         self.__attr_err = None
         self.__attr_err_timestamp = None
+        self.__attr_err_timeout = False
 
         # Lock for protecting the critical read region
         # where __attr_value and __attr_err are updated
@@ -344,8 +345,19 @@ class TangoAttribute(TaurusAttribute):
         auto_subscribe_conf = getattr(
             tauruscustomsettings, "TANGO_AUTOSUBSCRIBE_CONF", True
         )
+
+        # force read value if subscription to change events fails
+        self.force_read_if_subscription_fails = getattr(
+            tauruscustomsettings, "TANGO_FORCE_READ_IF_SUBSCRIPTION_FAILS"
+        )
+
+        # force read value if subscription to change events fails
+        self.events_to_subscribe = getattr(
+            tauruscustomsettings, "TANGO_EVENTS_TO_SUBSCRIBE"
+        )
+
         self.__cfg_evt_id = None
-        if auto_subscribe_conf and self.factory().is_tango_subscribe_enabled():
+        if auto_subscribe_conf:
             self._subscribeConfEvents()
 
     def __del__(self):
@@ -446,12 +458,14 @@ class TangoAttribute(TaurusAttribute):
                 PyTango.CmdArgType.DevEncoded,
             ):
                 attrvalue = magnitude
+            elif tgtype == PyTango.CmdArgType.DevEnum:
+                attrvalue = int(magnitude)
             else:
                 attrvalue = str(magnitude)
         elif fmt in (DataFormat._1D, DataFormat._2D):
             if PyTango.is_int_type(tgtype):
                 # cast to integer because the magnitude conversion gives floats
-                attrvalue = numpy.array(magnitude, copy=False, dtype="int64")
+                attrvalue = numpy.asarray(magnitude, dtype="int64")
             elif tgtype == PyTango.CmdArgType.DevUChar:
                 attrvalue = magnitude.view("uint8")
             else:
@@ -548,17 +562,71 @@ class TangoAttribute(TaurusAttribute):
                 self.__subscription_event.set()
                 self.fireEvent(TaurusEventType.Periodic, self.__attr_value)
 
+    def _read_hw(self):
+        # The read_attribute is called if not cache or if cached value is expired
+        with self.__read_lock:
+            try:
+                dev = self.getParentObj()
+                v = dev.read_attribute(self.getSimpleName())
+                self.__attr_value = self.decode(v)
+                self.__attr_err = None
+                self.__attr_err_timestamp = None
+                return self.__attr_value
+            except PyTango.DevFailed as df:
+                self.__attr_value = None
+                self.__attr_err = df
+                self.__attr_err_timestamp = time.time()
+                err = df.args[0]
+                self.debug(
+                    "[Tango] read failed (%s): %s", err.reason, err.desc
+                )
+                raise df
+            except Exception as e:
+                self.__attr_value = None
+                self.__attr_err = e
+                self.__attr_err_timestamp = time.time()
+                self.debug("[Tango] read failed: %s", e)
+                raise e
+
+    def _is_cache_empty(self):
+        return self.__attr_value is None and self.__attr_err is None
+
+    def _is_polling_or_subscribing(self):
+        return (
+            self.isPollingActive()
+            or self.__subscription_state == SubscriptionState.Subscribing
+        )
+
+    def _is_polling_or_subscribed(self):
+        return (
+            self.isPollingActive()
+            or self.__subscription_state == SubscriptionState.Subscribed
+        )
+
+    def _last_read_was_timeout(self):
+        if self.__attr_err is None:
+            return False
+        return (
+            len(self.__attr_err.args) == 2
+            and self.__attr_err.args[1].reason == TIMEOUT_EXCEPTION
+        )
+
     def read(self, cache=True):
         """Returns the current value of the attribute.
 
-        If `cache` is not False, or expired, or the attribute has events
-        active, then it will return the local cached value. Otherwise it will
-        read the attribute value from the tango device.
+        If `cache` is False it will force a read from the device and return
+        its value.
+        If `cache` is True, it will return the cached value.
+        If `cache` is a number, it will return the cached value if it's newer
+        than the specified number (in ms). Otherwise, it will act as if `cache`
+        is False.
+        If no cached value is available and `cache` is not False, it will wait
+        until the polling or an event fill the cache to return its value. If
+        polling is disabled and the attribute doesn't send events, it will act
+        as if `cache` is False.
 
-        The cached value expires if it is older than the value (im ms) passed
-        as the `cache` argument or the *polling period* if `cache==True`
-        (default). If the cache is expired a reading will be done just as if
-        cache was False.
+        If there is an application and it's starting, the cache validations are
+        skipped and returns de cached value or None if the cache is empty.
 
         :param cache: use cache value or make readout, eventually pass a
             cache's expiration period in milliseconds
@@ -566,71 +634,44 @@ class TangoAttribute(TaurusAttribute):
         :return: attribute value
         :rtype: :obj:`~taurus.core.tango.TangoAttributeValue`
         """
-        curr_time = time.time()
-        if cache:
-            try:
-                attr_timestamp = self.__attr_value.time.totime()
-            except AttributeError:
-                if self.__attr_err_timestamp is not None:
-                    attr_timestamp = self.__attr_err_timestamp
-                else:
-                    attr_timestamp = 0
-            dt = (curr_time - attr_timestamp) * 1000
-            if cache is True:  # cache *is* a bool True
-                expiration_period = self.getPollingPeriod()
-            else:  # cache is a non-zero numeric value
-                expiration_period = cache
-            if dt < expiration_period:
-                if self.__attr_value is not None:
-                    return self.__attr_value
-                elif self.__attr_err is not None:
-                    self.debug(
-                        "[Tango] read from cache failed (%s): %s",
-                        self.fullname,
-                        self.__attr_err,
-                    )
-                    raise self.__attr_err
 
-        if not cache or (
-            self.__subscription_state
-            in (
-                SubscriptionState.PendingSubscribe,
-                SubscriptionState.Unsubscribed,
-            )
-            and not self.isPollingActive()
-        ):
-            with self.__read_lock:
-                try:
-                    dev = self.getParentObj()
-                    v = dev.read_attribute(self.getSimpleName())
-                    self.__attr_value = self.decode(v)
-                    self.__attr_err = None
-                    self.__attr_err_timestamp = None
-                    return self.__attr_value
-                except PyTango.DevFailed as df:
-                    self.__attr_value = None
-                    self.__attr_err = df
-                    self.__attr_err_timestamp = curr_time
-                    err = df.args[0]
-                    self.debug(
-                        "[Tango] read failed (%s): %s", err.reason, err.desc
-                    )
-                    raise df
-                except Exception as e:
-                    self.__attr_value = None
-                    self.__attr_err = e
-                    self.__attr_err_timestamp = curr_time
-                    self.debug("[Tango] read failed: %s", e)
-                    raise e
-        elif self.__subscription_state in (
-            SubscriptionState.Subscribing,
-            SubscriptionState.PendingSubscribe,
-        ):
-            self.__subscription_event.wait()
+        if not cache:
+            return self._read_hw()
 
-        if self.__attr_err is not None:
+        if application.state == ApplicationStates.STARTING:
+            if self.__attr_err is not None:
+                raise self.__attr_err
+            return self.__attr_value
+
+        if self._is_cache_empty():
+            if self._is_polling_or_subscribing():
+                self.__subscription_event.wait()
+            else:
+                return self._read_hw()
+
+        # This avoids timeouts to stack calls when cache <= 3000
+        if self._last_read_was_timeout() and self._is_polling_or_subscribed():
             raise self.__attr_err
-        return self.__attr_value
+
+        if self.__attr_value is not None:
+            attr_timestamp = self.__attr_value.time.totime()
+        else:
+            attr_timestamp = self.__attr_err_timestamp
+
+        dt = (time.time() - attr_timestamp) * 1000
+        # cache *is* a bool True or is numeric and not expired
+        if cache is True or dt < cache:
+            if self.__attr_value is not None:
+                return self.__attr_value
+            elif self.__attr_err is not None:
+                self.debug(
+                    "[Tango] read from cache failed (%s): %s",
+                    self.fullname,
+                    self.__attr_err,
+                )
+                raise self.__attr_err
+
+        return self._read_hw()
 
     def getAttributeProxy(self):
         """Convenience method that creates and returns a PyTango.AttributeProxy
@@ -730,6 +771,18 @@ class TangoAttribute(TaurusAttribute):
     def _process_event_exception(self, ex):
         pass
 
+    def _should_force_read(self):
+        return (
+            application.state == ApplicationStates.STARTED
+            or self.force_read_if_subscription_fails
+            == tauruscustomsettings.FORCE_READ_OPTIONS.ALWAYS
+            or (
+                self.force_read_if_subscription_fails
+                == tauruscustomsettings.FORCE_READ_OPTIONS.ONLY_CORE
+                and application.state == ApplicationStates.NONE
+            )
+        )
+
     def _subscribeChangeEvents(self):
         """Enable subscription to the attribute events. If change events are
         not supported polling is activated
@@ -751,8 +804,16 @@ class TangoAttribute(TaurusAttribute):
                 self.debug("failed to subscribe to chg events: HW is None")
                 return
 
-        if not self.factory().is_tango_subscribe_enabled():
-            self.enablePolling(True)
+        # This hardcoded "CHANGE_EVENT" checking is temporal. This full method
+        # will be refactored when adding support other tango events so it will
+        # loop through the array instead of checking a specific value
+        if (
+            self.factory().is_tango_event_subscription_disabled()
+            or "CHANGE_EVENT" not in self.events_to_subscribe
+        ):
+            if self._should_force_read():
+                self.__attr_value = self.getValueObj(cache=False)
+            self._activatePolling()
             return
 
         try:
@@ -760,6 +821,8 @@ class TangoAttribute(TaurusAttribute):
             self._call_dev_hw_subscribe_event(False)
         except Exception:
             self.__subscription_state = SubscriptionState.PendingSubscribe
+            if self._should_force_read():
+                self.__attr_value = self.getValueObj(cache=False)
             self._activatePolling()
             self._call_dev_hw_subscribe_event(True)
 
@@ -899,7 +962,7 @@ class TangoAttribute(TaurusAttribute):
                 etype, evalue = self._pushAttrEvent(event)
 
             # notify the listeners if required (i.e, if etype is not None)
-            if etype is None:
+            if etype is None or evalue is None:
                 return
             manager = Manager()
             listeners = tuple(self._listeners)
@@ -958,7 +1021,7 @@ class TangoAttribute(TaurusAttribute):
             self.__subscription_state = SubscriptionState.Subscribed
             self.__subscription_event.set()
             if not self.isPollingForced():
-                self.disablePolling()
+                self._deactivatePolling()
             return TaurusEventType.Change, self.__attr_value
 
         elif event.errors[0].reason in EVENT_TO_POLLING_EXCEPTIONS:
@@ -993,12 +1056,7 @@ class TangoAttribute(TaurusAttribute):
         if not event.err:
             # update conf-related attributes
             self._decodeAttrInfoEx(event.attr_conf)
-            # make sure that there is a self.__attr_value
-            if self.__attr_value is None:
-                # TODO: maybe we can avoid this read?
-                self.__attr_value = self.getValueObj(cache=False)
             return TaurusEventType.Config, self.__attr_value
-
         else:
             self.__attr_value = None
             self.__attr_err = PyTango.DevFailed(*event.errors)
