@@ -46,7 +46,11 @@ from taurus.core.taurusbasetypes import (
 from taurus.core.taurusfactory import TaurusFactory
 from taurus.core.taurusbasetypes import OperationMode
 from taurus.core.taurusexception import TaurusException, DoubleRegistration
-from taurus.core.util.log import Logger, taurus4_deprecation
+from taurus.core.util.log import (
+    Logger,
+    taurus4_deprecation,
+    deprecation_decorator,
+)
 from taurus.core.util.singleton import Singleton
 from taurus.core.util.containers import CaselessWeakValueDict, CaselessDict
 
@@ -122,7 +126,7 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
     def reInit(self):
         """Reinitialize the singleton"""
         self._default_tango_host = None
-        self._tango_subscribe_enabled = True
+        self._event_subscription_disabled = None
         self.dft_db = None
         self.tango_db = CaselessWeakValueDict()
         self.tango_db_queries = CaselessWeakValueDict()
@@ -210,6 +214,9 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
         """Retruns the current default tango host"""
         return self._default_tango_host
 
+    @deprecation_decorator(
+        rel="5.2.1", alt="set_tango_event_subscription_disabled"
+    )
     def set_tango_subscribe_enabled(self, value):
         """If True, enables event subscribing on TangoAttribute objects
 
@@ -218,8 +225,11 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
                  may not be stable and/or it may be removed in a future release
                  (even on a minor version change)
         """
-        self._tango_subscribe_enabled = value
+        self.set_tango_event_subscription_disabled(not value)
 
+    @deprecation_decorator(
+        rel="5.2.1", alt="is_tango_event_subscription_disabled"
+    )
     def is_tango_subscribe_enabled(self):
         """Returns the current tango_subscribe_enabled status
 
@@ -228,7 +238,7 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
                  may not be stable and/or it may be removed in a future release
                  (even on a minor version change)
         """
-        return self._tango_subscribe_enabled
+        return not self.is_tango_event_subscription_disabled()
 
     def registerAttributeClass(self, attr_name, attr_klass):
         """Registers a new attribute class for the attribute name.
@@ -449,9 +459,9 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
                         )
                         kwargs["storeCallback"] = self._storeAttribute
                         if "pollingPeriod" not in kwargs:
-                            kwargs[
-                                "pollingPeriod"
-                            ] = self.getDefaultPollingPeriod()
+                            kwargs["pollingPeriod"] = (
+                                self.getDefaultPollingPeriod()
+                            )
                         attr = attr_klass(full_attr_name, dev, **kwargs)
                         # attribute objects will register themselves in this
                         # factory so there is no need to do it here
@@ -676,3 +686,12 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
         msg = "%s is deprecated (from %s). %s" % (dep, rel, dbg_msg)
         self.deprecated(msg)
         return OperationMode.ONLINE
+
+    def set_tango_event_subscription_disabled(self, disable_subscription):
+        """Disable subscription to tango events. Needs to be called before
+        creating Attributes or setting models
+        """
+        self._event_subscription_disabled = disable_subscription
+
+    def is_tango_event_subscription_disabled(self):
+        return self._event_subscription_disabled
