@@ -105,25 +105,38 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
     default_rvalue = {
         "bool": True,
         "int": 123,
-        "float": 1.23,
+        "float": numpy.float32(1.23),
+        "double": numpy.float64(1.23),
         "string": "hello world",
         "uchar": 1,
     }
-    default_unit = {"int": "mm", "float": "mm"}
+    default_unit = {"int": "mm", "float": "mm", "double": "mm"}
     # x10 default_rvalue
     default_ranges = {
         "int": [-default_rvalue["int"] * 10, default_rvalue["int"] * 10],
         "float": [-default_rvalue["float"] * 10, default_rvalue["float"] * 10],
+        "double": [
+            -default_rvalue["double"] * 10,
+            default_rvalue["double"] * 10,
+        ],
     }
     # x5 default_rvalue
     default_alarms = {
         "int": [-default_rvalue["int"] * 5, default_rvalue["int"] * 5],
         "float": [-default_rvalue["float"] * 5, default_rvalue["float"] * 5],
+        "double": [
+            -default_rvalue["double"] * 5,
+            default_rvalue["double"] * 5,
+        ],
     }
     # x3 default_rvalue
     default_warnings = {
         "int": [-default_rvalue["int"] * 3, default_rvalue["int"] * 3],
         "float": [-default_rvalue["float"] * 3, default_rvalue["float"] * 3],
+        "double": [
+            -default_rvalue["double"] * 3,
+            default_rvalue["double"] * 3,
+        ],
     }
     attrs = {
         "bool_scalar": dict(dtype=bool),
@@ -133,7 +146,9 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         "float_scalar_poll": dict(
             unit=default_unit["float"], dtype=numpy.float32, polling_period=500
         ),
-        "double_scalar": dict(unit=default_unit["float"], dtype=numpy.float64),
+        "double_scalar": dict(
+            unit=default_unit["double"], dtype=numpy.float64
+        ),
         "string_scalar": dict(dtype=str),
         "uchar_scalar": dict(unit=default_unit["int"], dtype=numpy.uint8),
         "bool_spectrum": dict(dtype=(bool,), max_dim_x=MAXDIMX),
@@ -146,7 +161,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
             max_dim_x=MAXDIMX,
         ),
         "double_spectrum": dict(
-            unit=default_unit["float"],
+            unit=default_unit["double"],
             dtype=(numpy.float64,),
             max_dim_x=MAXDIMX,
         ),
@@ -170,7 +185,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
             max_dim_y=MAXDIMY,
         ),
         "double_image": dict(
-            unit=default_unit["float"],
+            unit=default_unit["double"],
             dtype=[(numpy.float64,)],
             max_dim_x=MAXDIMX,
             max_dim_y=MAXDIMY,
@@ -204,12 +219,12 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
             max_warning=default_warnings["float"][1],
         ),
         "double_scalar": dict(
-            min_value=default_ranges["float"][0],
-            max_value=default_ranges["float"][1],
-            min_alarm=default_alarms["float"][0],
-            max_alarm=default_alarms["float"][1],
-            min_warning=default_warnings["float"][0],
-            max_warning=default_warnings["float"][1],
+            min_value=default_ranges["double"][0],
+            max_value=default_ranges["double"][1],
+            min_alarm=default_alarms["double"][0],
+            max_alarm=default_alarms["double"][1],
+            min_warning=default_warnings["double"][0],
+            max_warning=default_warnings["double"][1],
         ),
     }
 
@@ -380,7 +395,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         return self.default_rvalue["float"]
 
     def read_double_scalar_ro(self):
-        return self.default_rvalue["float"]
+        return self.default_rvalue["double"]
 
     def read_string_scalar_ro(self):
         return self.default_rvalue["string"]
@@ -399,7 +414,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         return [self.default_rvalue["float"]] * self.DIMX
 
     def read_double_spectrum_ro(self):
-        return [self.default_rvalue["float"]] * self.DIMX
+        return [self.default_rvalue["double"]] * self.DIMX
 
     def read_string_spectrum_ro(self):
         return [self.default_rvalue["string"]] * self.DIMX
@@ -415,7 +430,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         return [[self.default_rvalue["float"]] * self.DIMX] * self.DIMY
 
     def read_double_image_ro(self):
-        return [[self.default_rvalue["float"]] * self.DIMX] * self.DIMY
+        return [[self.default_rvalue["double"]] * self.DIMX] * self.DIMY
 
     def read_string_image_ro(self):
         return [[self.default_rvalue["string"]] * self.DIMX] * self.DIMY
@@ -453,7 +468,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         self._float_scalar = v
 
     def read_double_scalar(self):
-        return getattr(self, "_double_scalar", self.default_rvalue["float"])
+        return getattr(self, "_double_scalar", self.default_rvalue["double"])
 
     def write_double_scalar(self, v):
         self._double_scalar = v
@@ -501,7 +516,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         return getattr(
             self,
             "_double_spectrum",
-            [self.default_rvalue["float"]] * self.DIMX,
+            [self.default_rvalue["double"]] * self.DIMX,
         )
 
     def write_double_spectrum(self, v):
@@ -560,7 +575,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         return getattr(
             self,
             "_double_image",
-            [[self.default_rvalue["float"]] * self.DIMX] * self.DIMY,
+            [[self.default_rvalue["double"]] * self.DIMX] * self.DIMY,
         )
 
     def write_double_image(self, v):
@@ -709,7 +724,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
                     warning = self.default_warnings["int"]
                     attrInfoex.min_warning = str(warning[0])
                     attrInfoex.max_warning = str(warning[1])
-                elif attr in ["float_scalar", "double_scalar"]:
+                elif attr == "float_scalar":
                     range = self.default_ranges["float"]
                     attrInfoex.min_value = str(range[0])
                     attrInfoex.max_value = str(range[1])
@@ -719,19 +734,29 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
                     warning = self.default_warnings["float"]
                     attrInfoex.min_warning = str(warning[0])
                     attrInfoex.max_warning = str(warning[1])
+                elif attr == "double_scalar":
+                    range = self.default_ranges["double"]
+                    attrInfoex.min_value = str(range[0])
+                    attrInfoex.max_value = str(range[1])
+                    alarm = self.default_alarms["double"]
+                    attrInfoex.min_alarm = str(alarm[0])
+                    attrInfoex.max_alarm = str(alarm[1])
+                    warning = self.default_warnings["double"]
+                    attrInfoex.min_warning = str(warning[0])
+                    attrInfoex.max_warning = str(warning[1])
             dev.set_attribute_config(attrInfoex)
         # Reset the attributes value
         self._boolean_scalar = self.default_rvalue["bool"]
         self._short_scalar = self.default_rvalue["int"]
         self._short_scalar_nu = self.default_rvalue["int"]
         self._float_scalar = self.default_rvalue["float"]
-        self._double_scalar = self.default_rvalue["float"]
+        self._double_scalar = self.default_rvalue["double"]
         self._string_scalar = self.default_rvalue["string"]
         self._uchar_scalar = self.default_rvalue["uchar"]
         self._boolean_spectrum = [self.default_rvalue["bool"]] * self.DIMX
         self._short_spectrum = [self.default_rvalue["int"]] * self.DIMX
         self._float_spectrum = [self.default_rvalue["float"]] * self.DIMX
-        self._double_spectrum = [self.default_rvalue["float"]] * self.DIMX
+        self._double_spectrum = [self.default_rvalue["double"]] * self.DIMX
         self._string_spectrum = [self.default_rvalue["string"]] * self.DIMX
         self._uchar_spectrum = [self.default_rvalue["uchar"]] * self.DIMX
         v = [[self.default_rvalue["bool"]] * self.DIMX] * self.DIMY
@@ -740,7 +765,7 @@ class TangoSchemeTest(Device, metaclass=__DeviceMeta):
         self._short_image = v
         v = [[self.default_rvalue["float"]] * self.DIMX] * self.DIMY
         self._float_image = v
-        v = [[self.default_rvalue["float"]] * self.DIMX] * self.DIMY
+        v = [[self.default_rvalue["double"]] * self.DIMX] * self.DIMY
         self._double_image = v
         v = [[self.default_rvalue["string"]] * self.DIMX] * self.DIMY
         self._string_image = v
