@@ -44,8 +44,9 @@ from .nodb import nodb_dev  # noqa
 
 _INT_IMG = numpy.arange(2 * 3, dtype="int16").reshape((2, 3))
 _INT_SPE = _INT_IMG[1, :]
-_FLOAT_IMG = _INT_IMG * 0.1
-_FLOAT_SPE = _INT_SPE * 0.1
+_FLOAT_IMG = numpy.linspace(0.1, 0.6, 6, dtype=numpy.float32).reshape((2, 3))
+_FLOAT_SPE = _FLOAT_IMG[1, :]
+_FLOAT32_SCALAR_RO = numpy.float32(1.23)
 _BOOL_IMG = numpy.array([[True, False], [False, True]])
 _BOOL_SPE = [True, False]
 _STR = "foo BAR |-+#@!?_[]{}"
@@ -53,6 +54,14 @@ _UINT8_IMG = numpy.array([[1, 2], [3, 4]], dtype="uint8")
 _UINT8_SPE = _UINT8_IMG[1, :]
 
 
+def _npfloat32(val):
+    return numpy.float32(val)
+
+
+def _npfloat64(val):
+    return numpy.float64(val)
+
+
 def _assertValidValue(exp, got, msg):
     # if we are dealing with quantities, use the magnitude for comparing
     if isinstance(got, Quantity):
@@ -68,7 +77,7 @@ def _assertValidValue(exp, got, msg):
         # some cases may fail the simple equality but still be True
         try:
             # for those values that can be handled by numpy.allclose()
-            chk = numpy.allclose(got, exp)
+            chk = numpy.allclose(got, exp, rtol=1e-15)
         except Exception:
             if isinstance(got, numpy.ndarray):
                 # uchars were not handled with allclose
@@ -130,14 +139,14 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
         ),
         (
             "boolean_spectrum",
-            numpy.empty(0, dtype="bool8"),
+            numpy.empty(0, dtype="bool"),
             dict(type=DataType.Boolean),
             None,
             (0,),
         ),
         (
             "boolean_image",
-            numpy.empty((0, 0), dtype="bool8"),
+            numpy.empty((0, 0), dtype="bool"),
             dict(type=DataType.Boolean),
             None,
             (0, 0),
@@ -428,88 +437,120 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
         ),
         (
             "float_scalar",
-            Quantity(0.01, "m"),
+            Quantity(_npfloat32(0.01), "m"),
             dict(
-                rvalue=Quantity(0.01, "m"),
-                wvalue=Quantity(10, "mm"),
+                rvalue=Quantity(_npfloat32(0.01), "m"),
+                wvalue=Quantity(_npfloat32(10), "mm"),
                 type=DataType.Float,
                 name="float_scalar",
-                range=[Quantity(-12.30, "mm"), Quantity(12.30, "mm")],
-                alarms=[Quantity(-6.15, "mm"), Quantity(6.15, "mm")],
-                warnings=[Quantity(-3.69, "mm"), Quantity(3.69, "mm")],
+                range=[
+                    Quantity(_npfloat32(-12.30), "mm"),
+                    Quantity(_npfloat32(12.30), "mm"),
+                ],
+                alarms=[
+                    Quantity(_npfloat32(-6.15), "mm"),
+                    Quantity(_npfloat32(6.15), "mm"),
+                ],
+                warnings=[
+                    Quantity(_npfloat32(-3.69), "mm"),
+                    Quantity(_npfloat32(3.69), "mm"),
+                ],
             ),
             dict(
-                value=10,
-                rvalue=Quantity(0.01, "m"),
-                w_value=10,
-                wvalue=Quantity(10, "mm"),
+                value=_npfloat32(10),
+                rvalue=Quantity(_npfloat32(0.01), "m"),
+                w_value=_npfloat32(10),
+                wvalue=Quantity(_npfloat32(10), "mm"),
                 quality=AttrQuality.ATTR_ALARM,
             ),
             None,
         ),
         (
             "float_scalar",
-            Quantity(0.004, "m"),
-            dict(rvalue=Quantity(4, "mm"), wvalue=Quantity(4, "mm")),
+            Quantity(_npfloat32(0.004), "m"),
             dict(
-                rvalue=Quantity(4, "mm"),
-                wvalue=Quantity(0.004, "m"),
+                rvalue=Quantity(_npfloat32(4), "mm"),
+                wvalue=Quantity(_npfloat32(4), "mm"),
+            ),
+            dict(
+                rvalue=Quantity(_npfloat32(4), "mm"),
+                wvalue=Quantity(_npfloat32(0.004), "m"),
                 quality=AttrQuality.ATTR_WARNING,
             ),
             None,
         ),
         (
             "float_scalar",
-            Quantity(3, "mm"),
+            Quantity(_npfloat32(3), "mm"),
             dict(
-                rvalue=Quantity(3, "mm"),
-                wvalue=Quantity(3, "mm"),
+                rvalue=Quantity(_npfloat32(3), "mm"),
+                wvalue=Quantity(_npfloat32(3), "mm"),
                 type=DataType.Float,
             ),
-            dict(value=3, w_value=3, quality=AttrQuality.ATTR_VALID),
+            dict(
+                value=_npfloat32(3),
+                w_value=_npfloat32(3),
+                quality=AttrQuality.ATTR_VALID,
+            ),
             None,
         ),
         (
             "double_scalar",
-            Quantity(0.01, "m"),
+            Quantity(_npfloat64(0.01), "m"),
             dict(
-                rvalue=Quantity(0.01, "m"),
-                wvalue=Quantity(10, "mm"),
+                rvalue=Quantity(_npfloat64(0.01), "m"),
+                wvalue=Quantity(_npfloat64(10), "mm"),
                 type=DataType.Float,
                 name="double_scalar",
-                range=[Quantity(-12.30, "mm"), Quantity(12.30, "mm")],
-                alarms=[Quantity(-6.15, "mm"), Quantity(6.15, "mm")],
-                warnings=[Quantity(-3.69, "mm"), Quantity(3.69, "mm")],
+                range=[
+                    Quantity(_npfloat64(-12.30), "mm"),
+                    Quantity(_npfloat64(12.30), "mm"),
+                ],
+                alarms=[
+                    Quantity(_npfloat64(-6.15), "mm"),
+                    Quantity(_npfloat64(6.15), "mm"),
+                ],
+                warnings=[
+                    Quantity(_npfloat64(-3.69), "mm"),
+                    Quantity(_npfloat64(3.69), "mm"),
+                ],
             ),
             dict(
-                value=10,
-                rvalue=Quantity(0.01, "m"),
-                w_value=10,
-                wvalue=Quantity(10, "mm"),
+                value=_npfloat64(10),
+                rvalue=Quantity(_npfloat64(0.01), "m"),
+                w_value=_npfloat64(10),
+                wvalue=Quantity(_npfloat64(10), "mm"),
                 quality=AttrQuality.ATTR_ALARM,
             ),
             None,
         ),
         (
             "double_scalar",
-            Quantity(0.004, "m"),
-            dict(rvalue=Quantity(4, "mm"), wvalue=Quantity(4, "mm")),
+            Quantity(_npfloat64(0.004), "m"),
             dict(
-                rvalue=Quantity(4, "mm"),
-                wvalue=Quantity(0.004, "m"),
+                rvalue=Quantity(_npfloat64(4), "mm"),
+                wvalue=Quantity(_npfloat64(4), "mm"),
+            ),
+            dict(
+                rvalue=Quantity(_npfloat64(4), "mm"),
+                wvalue=Quantity(_npfloat64(0.004), "m"),
                 quality=AttrQuality.ATTR_WARNING,
             ),
             None,
         ),
         (
             "double_scalar",
-            Quantity(3, "mm"),
+            Quantity(_npfloat64(3), "mm"),
             dict(
-                rvalue=Quantity(3, "mm"),
-                wvalue=Quantity(3, "mm"),
+                rvalue=Quantity(_npfloat64(3), "mm"),
+                wvalue=Quantity(_npfloat64(3), "mm"),
                 type=DataType.Float,
             ),
-            dict(value=3, w_value=3, quality=AttrQuality.ATTR_VALID),
+            dict(
+                value=_npfloat64(3),
+                w_value=_npfloat64(3),
+                quality=AttrQuality.ATTR_VALID,
+            ),
             None,
         ),
         (
@@ -693,21 +734,27 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
             "float_image_ro",
             None,
             dict(
-                rvalue=Quantity([[1.23] * 3] * 3, "mm"),
-                wvalue=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                rvalue=Quantity([[_FLOAT32_SCALAR_RO] * 3] * 3, "mm"),
+                wvalue=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 type=DataType.Float,
             ),
             dict(
-                value=[[1.23] * 3] * 3,
-                w_value=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                value=[[_FLOAT32_SCALAR_RO] * 3] * 3,
+                w_value=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 quality=AttrQuality.ATTR_VALID,
-                wvalue=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                wvalue=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
             ),
             (3, 3),
         ),
@@ -715,17 +762,21 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
             "float_spectrum_ro",
             None,
             dict(
-                rvalue=Quantity([1.23] * 3, "mm"),
-                wvalue=Quantity([], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                rvalue=Quantity([_FLOAT32_SCALAR_RO] * 3, "mm"),
+                wvalue=(
+                    Quantity([], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 type=DataType.Float,
             ),
             dict(
-                value=[1.23] * 3,
-                w_value=Quantity([], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                value=[_FLOAT32_SCALAR_RO] * 3,
+                w_value=(
+                    Quantity([], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 quality=AttrQuality.ATTR_VALID,
             ),
             (3,),
@@ -734,7 +785,7 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
             "float_scalar_ro",
             None,
             dict(
-                rvalue=Quantity(1.23, "mm"),
+                rvalue=Quantity(_FLOAT32_SCALAR_RO, "mm"),
                 wvalue=None,
                 type=DataType.Float,
                 writable=False,
@@ -751,7 +802,11 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
                     Quantity(float("inf"), "mm"),
                 ],
             ),
-            dict(value=1.23, w_value=None, quality=AttrQuality.ATTR_VALID),
+            dict(
+                value=_FLOAT32_SCALAR_RO,
+                w_value=None,
+                quality=AttrQuality.ATTR_VALID,
+            ),
             None,
         ),
         (
@@ -759,21 +814,27 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
             None,
             dict(
                 rvalue=Quantity([[123] * 3] * 3, "mm"),
-                wvalue=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                wvalue=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 type=DataType.Integer,
             ),
             dict(
                 rvalue=Quantity([[123] * 3] * 3, "mm"),
                 value=[[123] * 3] * 3,
                 quality=AttrQuality.ATTR_VALID,
-                wvalue=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
-                w_value=Quantity([[]], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                wvalue=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
+                w_value=(
+                    Quantity([[]], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
             ),
             (3, 3),
         ),
@@ -782,9 +843,11 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
             None,
             dict(
                 rvalue=Quantity([123] * 3, "mm"),
-                wvalue=Quantity([], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                wvalue=(
+                    Quantity([], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
                 type=DataType.Integer,
                 data_format=DataFormat._1D,
                 writable=False,
@@ -793,12 +856,16 @@ def _getDecodePyTangoAttr(dev_name, attr_name, cfg):
                 rvalue=Quantity([123] * 3, "mm"),
                 value=[123] * 3,
                 quality=AttrQuality.ATTR_VALID,
-                wvalue=Quantity([], "mm")
-                if tango.Release.version_number >= 940
-                else None,
-                w_value=Quantity([], "mm")
-                if tango.Release.version_number >= 940
-                else None,
+                wvalue=(
+                    Quantity([], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
+                w_value=(
+                    Quantity([], "mm")
+                    if tango.Release.version_number >= 940
+                    else None
+                ),
             ),
             (3,),
         ),
@@ -935,8 +1002,8 @@ def test_write_read_attr(
         (
             "float_scalar",
             "range",
-            [Quantity(-5, "mm"), Quantity(5, "mm")],
-            [Quantity(-0.005, "m"), Quantity(5, "mm")],
+            [Quantity(_npfloat32(-5), "mm"), Quantity(_npfloat32(5), "mm")],
+            [Quantity(_npfloat32(-0.005), "m"), Quantity(_npfloat32(5), "mm")],
         ),
         ("short_spectrum", "label", "Just a Test", "Just a Test"),
         ("boolean_spectrum", "label", "Just_a_Test", "Just_a_Test"),
@@ -955,8 +1022,14 @@ def test_write_read_attr(
         (
             "float_image",
             "warnings",
-            [Quantity(-0.75, "mm"), Quantity(0.75, "mm")],
-            [Quantity(-0.00075, "m"), Quantity(0.75, "mm")],
+            [
+                Quantity(_npfloat32(-0.75), "mm"),
+                Quantity(_npfloat32(0.75), "mm"),
+            ],
+            [
+                Quantity(_npfloat32(-0.00075), "m"),
+                Quantity(_npfloat32(0.75), "mm"),
+            ],
         ),
         (
             "short_scalar_nu",
@@ -979,8 +1052,14 @@ def test_write_read_attr(
         (
             "float_image",
             "alarms",
-            [Quantity(-0.75, "mm"), Quantity(0.75, "mm")],
-            [Quantity(-0.00075, "m"), Quantity(0.75, "mm")],
+            [
+                Quantity(_npfloat32(-0.75), "mm"),
+                Quantity(_npfloat32(0.75), "mm"),
+            ],
+            [
+                Quantity(_npfloat32(-0.00075), "m"),
+                Quantity(_npfloat32(0.75), "mm"),
+            ],
         ),
         (
             "short_scalar_nu",
