@@ -34,7 +34,7 @@ from taurus.core.taurusdevice import TaurusDevice
 from taurus.qt.qtgui.base import TaurusBaseWidget
 from taurus.core.util import eventfilters
 from taurus.qt.qtgui.dialog import ProtectTaurusMessageBox
-
+from taurus.taurusstatecontroller import application
 
 __docformat__ = "restructuredtext"
 
@@ -246,6 +246,7 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
         Note that the dialog will only be created once. Subsequent clicks on
         the button will only raise the existing dialog
         """
+        application.application_starting()
         if self.widget() is None:
             self.createWidget()
         self.widget().setModel(self.getModelName())
@@ -258,6 +259,7 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
 
         self._dialog.show()
         self._dialog.raise_()
+        application.application_started()
 
     @classmethod
     def getQtDesignerPluginInfo(cls):
