@@ -217,7 +217,9 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
     #: Message for splash screen
     SPLASH_MESSAGE = "Initializing Main window..."
     #: Whether to save settings before closing. Set to None to ask the user
-    SAVE_SETTINGS_ON_CLOSE = None
+    SAVE_SETTINGS_ON_CLOSE = getattr(
+        tauruscustomsettings, "SAVE_SETTINGS_ON_CLOSE"
+    )
 
     _old_options_api = {
         "_heartbeat": "HEARTBEAT",
@@ -348,6 +350,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         self.fileMenu = self.menuBar().addMenu("File")
         if self.USER_PERSPECTIVES_ENABLED:
             self.fileMenu.addAction(self.importSettingsFileAction)
+            self.fileMenu.addAction(self.saveSettingsFileAction)
             self.fileMenu.addAction(self.exportSettingsFileAction)
             # self.fileMenu.addAction(self.resetSettingsAction)
             self.fileMenu.addSeparator()
@@ -503,14 +506,18 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         )
 
         self.exportSettingsFileAction = Qt.QAction(
-            Qt.QIcon.fromTheme("document-save"), "Export Settings ...", self
+            Qt.QIcon.fromTheme("document-save-as"), "Export Settings...", self
         )
         self.exportSettingsFileAction.triggered.connect(
             partial(self.exportSettingsFile, fname=None)
         )
+        self.saveSettingsFileAction = Qt.QAction(
+            Qt.QIcon.fromTheme("document-save"), "Save Settings", self
+        )
+        self.saveSettingsFileAction.triggered.connect(self.saveSettingsFile)
 
         self.importSettingsFileAction = Qt.QAction(
-            Qt.QIcon.fromTheme("document-open"), "Import Settings ...", self
+            Qt.QIcon.fromTheme("document-open"), "Import Settings...", self
         )
         self.importSettingsFileAction.triggered.connect(
             partial(self.importSettingsFile, fname=None)
@@ -717,7 +724,6 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         ignoreGeometry=False,
         factorySettingsFileName=None,
     ):
-
         """restores the application settings previously saved with
         :meth:`saveSettings`.
 
@@ -964,7 +970,18 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
             self.info('MainWindow settings saved in "%s"' % str(fname))
         else:
             msg = "Settings could not be exported to %s" % str(fname)
-            Qt.QMessageBox.warning(self, "Export error", msg)
+            Qt.QMessageBox.warning(self, "Export error:", msg)
+
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot("QString")
+    def saveSettingsFile(self):
+        """Save the current settings into default file."""
+        try:
+            self.saveSettings()
+            self.info("MainWindow settings saved.")
+        except Exception:
+            msg = "Settings could not be exported."
+            Qt.QMessageBox.warning(self, "Export error:", msg)
 
     @Qt.pyqtSlot()
     @Qt.pyqtSlot("QString")
