@@ -42,7 +42,7 @@ from taurus.qt.qtgui.base import TaurusBaseController
 from taurus.qt.qtgui.base import TaurusScalarAttributeControllerHelper
 from taurus.qt.qtgui.base import TaurusConfigurationControllerHelper
 from taurus.qt.qtgui.base import updateLabelBackground
-
+from taurus.qt.qtgui.base import TaurusBgRoleSubscriber
 
 __docformat__ = "restructuredtext"
 
@@ -338,6 +338,8 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def handleEvent(self, evt_src, evt_type, evt_value):
+        if evt_type in (TaurusEventType.Change, TaurusEventType.Periodic):
+            self.emitValueChanged()
         ctrl = self.controller()
         if ctrl is not None:
             ctrl.handleEvent(evt_src, evt_type, evt_value)
@@ -406,6 +408,18 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
                      and its API may change in future versions
         """
         self._bgRole = str(bgRole)
+        if self._bgRole in ["tango_state"]:
+            _bgRoleSubscriber = TaurusBgRoleSubscriber(self)
+            _bgRoleSubscriber.setModel(f"{self.modelObj.parentObj.name}/state")
+        elif "parentObj." in self._bgRole:
+            _attr = self._bgRole.split(".")[1]
+            if "Obj" in _attr:
+                _attr = _attr.strip("Obj")
+            _bgRoleSubscriber = TaurusBgRoleSubscriber(self)
+            _bgRoleSubscriber.setModel(
+                f"{self.modelObj.parentObj.name}/{_attr}"
+            )
+
         self.controllerUpdate()
 
     def resetBgRole(self):
