@@ -103,7 +103,7 @@ class TaurusCurveDialog(CurveDialog, TaurusBaseWidget):
         as separators)
         """
         if isinstance(modelNames, str):
-            modelNames = str(modelNames).replace(",", " ")
+            modelNames = str(modelNames).replace(";", " ")
             modelNames = modelNames.split()
         return modelNames
 
@@ -295,7 +295,7 @@ class TaurusTrendDialog(CurveDialog, TaurusBaseWidget):
         as separators)
         """
         if isinstance(modelNames, str):
-            modelNames = str(modelNames).replace(",", " ")
+            modelNames = str(modelNames).replace(";", " ")
             modelNames = modelNames.split()
         return modelNames
 
@@ -533,6 +533,13 @@ class TaurusImageDialog(ImageDialog, TaurusBaseWidget):
         self.imgItem = None
         from taurus.qt.qtgui.extra_guiqwt.tools import TaurusModelChooserTool
 
+        # Temporarily remove the Print option due to an issue with the guiqwt
+        # library. It can be re-enabled once the issue is resolved. For more
+        # details, see: https://gitlab.com/taurus-org/taurus/-/issues/1334
+        for action in self.get_toolbar().actions():
+            if action.text() == "Print...":
+                self.get_toolbar().removeAction(action)
+
         self.add_tool(TaurusModelChooserTool, singleModel=True)
         self.setModifiableByUser(True)
         self.setContextMenuPolicy(Qt.Qt.CustomContextMenu)
