@@ -34,7 +34,7 @@ import subprocess
 import traceback
 import importlib
 from collections.abc import Sequence
-from queue import Queue
+import queue
 
 from taurus import Manager
 from taurus.core import AttrQuality, DataType
@@ -92,13 +92,18 @@ class QEmitter(Qt.QObject):
 
 
 class TaurusGraphicsUpdateThread(Qt.QThread):
-    def __init__(self, parent=None, period=3):
-        """Parent most not be None and must be a TaurusGraphicsScene!"""
-        if not isinstance(parent, TaurusGraphicsScene):
-            raise RuntimeError("Illegal parent for TaurusGraphicsUpdateThread")
+    """
+    Thread to update the :class:`TaurusGraphicsScene`.
+    """
+
+    def __init__(self, parent, scene, period=3):
+        if not isinstance(scene, TaurusGraphicsScene):
+            raise RuntimeError("Illegal scene for TaurusGraphicsUpdateThread")
         Qt.QThread.__init__(self, parent)
+        self.scene = scene
         self.period = period
         self.log = Logger("TaurusGraphicsUpdateThread")
+        self._emitter = self._createEmitter()
 
     def _updateView(self, v):
         # The first one is the prefered one because it improves performance
@@ -116,16 +121,20 @@ class TaurusGraphicsUpdateThread(Qt.QThread):
         #     # v.invalidateScene(item.boundingRect())
         return
 
+    def _createEmitter(self):
+        """This have to be called by the scene thread"""
+        emitter = QEmitter(Qt.QApplication.instance())
+        emitter.moveToThread(Qt.QApplication.instance().thread())
+        emitter.updateView.connect(self._updateView)
+        return emitter
+
     def run(self):
         self.log.debug("run... - TaurusGraphicsUpdateThread")
-        emitter = QEmitter()
-        emitter.moveToThread(Qt.QApplication.instance().thread())
-        emitter.setParent(Qt.QApplication.instance())
-        emitter.updateView.connect(self._updateView)
 
-        p = self.parent()
+        scene = self.scene
+        emitter = self._emitter
         while True:
-            item = p.getQueue().get(True)
+            item = scene.getQueue().get(True)
             if type(item) in (str,):
                 if item == "exit":
                     break
@@ -138,15 +147,16 @@ class TaurusGraphicsUpdateThread(Qt.QThread):
             #       probably related to todo in _updateView()
             # item_rects = [i.boundingRect() for i in item]
 
-            for v in p.views():
-                # p.debug("emit('updateView')")
-                # emitter.updateView.emit(v)
+            for v in scene.views():
+                # scene.debug("emit('updateView')")
                 emitter.updateView.emit(v)
             # This sleep is needed to reduce CPU usage of the application!
             self.sleep(self.period)
             # End of while
         # End of Thread
 
+        self.log.debug("stop - TaurusGraphicsUpdateThread")
+
 
 class TaurusGraphicsScene(Qt.QGraphicsScene):
     """
@@ -232,9 +242,14 @@ class TaurusGraphicsScene(Qt.QGraphicsScene):
         if strt:
             self.start()
 
+        self.destroyed.connect(self.stop)
+        if parent is not None:
+            # Stop connected to a QWidget sounds safer
+            parent.destroyed.connect(self.stop)
+
     def __del__(self):
         self.closeAllPanels()
-        Qt.QGraphicsScene.__del__(self)
+        self.stop()
 
     def showNewPanel(self, args=None, standAlone=False):
         try:
@@ -457,7 +472,7 @@ class TaurusGraphicsScene(Qt.QGraphicsScene):
                         configDialogAction = menu.addAction(k)
                         if action:
                             configDialogAction.triggered.connect(
-                                lambda dev=obj_name, act=action: act(dev)
+                                lambda: action(obj_name)
                             )
                         else:
                             configDialogAction.setEnabled(False)
@@ -981,10 +996,26 @@ class TaurusGraphicsScene(Qt.QGraphicsScene):
     def start(self):
         if self.updateThread:
             return
-        self.updateQueue = Queue()
-        self.updateThread = TaurusGraphicsUpdateThread(self)
+        self.updateQueue = queue.Queue()
+        self.updateThread = TaurusGraphicsUpdateThread(None, self)
         self.updateThread.start()  # Qt.QThread.HighPriority)
 
+    def stop(self):
+        if not self.updateThread:
+            return
+
+        # Clear the queue
+        # No need to process anything anymore
+        try:
+            while True:
+                self.updateQueue.get(False)
+        except queue.Empty:
+            pass
+
+        self.updateQueue.put("exit")
+        self.updateThread.wait()
+        self.updateThread = None
+
     def getQueue(self):
         return self.updateQueue
 
