@@ -318,7 +318,8 @@ class TaurusDevicePanel(TaurusWidget):
         model, modelclass, raw = str(model).strip(), "", model
         if model:
             model = model and model.split()[0] or ""
-            modelclass = taurus.Factory().findObjectClass(model)
+            scheme = taurus.Manager().getScheme(model)
+            modelclass = taurus.Factory(scheme).findObjectClass(model)
         self.trace(
             "In TaurusDevicePanel.setModel(%s(%s),%s)"
             % (raw, modelclass, pixmap)
@@ -531,11 +532,11 @@ class TaurusDevicePanel(TaurusWidget):
             form.setModel(device)
             if params:
                 form.setSortKey(
-                    lambda x, vals=[s[0].lower() for s in params]: vals.index(
-                        x.cmd_name.lower()
+                    lambda x, vals=[s[0].lower() for s in params]: (
+                        vals.index(x.cmd_name.lower())
+                        if str(x.cmd_name).lower() in vals
+                        else 100
                     )
-                    if str(x.cmd_name).lower() in vals
-                    else 100
                 )
                 form.setViewFilters(
                     [
