@@ -301,7 +301,7 @@ class TaurusForm(TaurusWidget):
         if isinstance(modelNames, bytes):
             modelNames = modelNames.decode()
         if isinstance(modelNames, str):
-            modelNames = str(modelNames).replace(",", " ")
+            modelNames = str(modelNames).replace(";", " ")
             modelNames = modelNames.split()
         return modelNames
 
