@@ -258,7 +258,9 @@ class TaurusValuesIOTableModel(Qt.QAbstractTableModel):
         if self._attr.getType() in [DataType.Float, DataType.Integer]:
             units = self._parent.getCurrentUnits()
             value = _value2Quantity(value, units)
-            equals = numpy.allclose(rtable_value, value.to(units))
+            equals = numpy.allclose(
+                rtable_value, value.to(units), rtol=1e-15, atol=1e-15
+            )
         else:
             equals = bool(rtable_value == value)
         if not equals:
