@@ -288,7 +288,7 @@ class ProjectPage(BasePage):
                     Qt.QMessageBox.warning(
                         self,
                         "Error loading project configuration",
-                        "Could not load the existing configuration.\nReason:%s"
+                        "Could not load the existing configuration.\nReason: %s"
                         % repr(e),
                         Qt.QMessageBox.Cancel,
                     )
@@ -1712,9 +1712,10 @@ class AppSettingsWizard(Qt.QWizard):
         f = open(fname, "r")
         xml = f.read()
         root = etree.fromstring(xml)
-
-        for pageNumber in range(len(self.Pages)):
-            self.page(pageNumber).fromXml(root)
+        nextId = 0
+        while nextId > -1:
+            self.page(nextId).fromXml(root)
+            nextId = self.page(nextId).nextId()
 
     def getXml(self):
         try:
