@@ -195,7 +195,7 @@ class WidgetPage(Qt.QWizardPage, TaurusBaseWidget):
         "taurus_pyqtgraph:TaurusPlot",
         "taurus.qt.qtgui.extra_guiqwt:TaurusImageDialog",
         "taurus.qt.qtgui.extra_guiqwt:TaurusTrend2DDialog",
-        "taurus.qt.qtgui.extra_guiqwt:TaurusNeXusBrowser",
+        "taurus.qt.qtgui.extra_nexus:TaurusNeXusBrowser",
         "taurus.qt.qtgui.tree:TaurusDbTreeWidget",
         "sardana.taurus.qt.qtgui.extra_sardana:SardanaEditor",
         "taurus.qt.qtgui.graphic.jdraw:TaurusJDrawSynopticsView",
