@@ -44,7 +44,7 @@ from taurus.qt.qtcore.configuration import (
 )
 from taurus.qt.qtcore.communication import SharedDataManager
 from taurus.qt.qtgui.base import TaurusBaseWidget, TaurusBaseComponent
-from taurus.qt.qtgui.container import TaurusMainWindow
+from taurus.qt.qtgui.container import TaurusMainWindow, TaurusWidget
 from taurus.qt.qtgui.taurusgui.utils import (
     ExternalApp,
     PanelDescription,
@@ -640,10 +640,8 @@ class TaurusGui(TaurusMainWindow):
                 return
         name = str(name)
         if name not in apps:
-            msg = (
-                'Cannot remove the external application "%s"'
-                " (not found)" % name
-            )
+            msg = "Cannot remove the external application "
+            "'{}' (not found)".format(name)
             self.debug(msg)
             return
         if name in list(self.__external_app.keys()):
@@ -727,7 +725,7 @@ class TaurusGui(TaurusMainWindow):
                 return
         name = str(name)
         if name not in self.__panels:
-            self.debug('Cannot remove panel "%s" (not found)' % name)
+            self.debug('Cannot remove panel "{}" (not found)'.format(name))
             return
         panel = self.__panels.pop(name)
         try:
@@ -1047,16 +1045,7 @@ class TaurusGui(TaurusMainWindow):
                 "Error loading synoptic file '%s'."
                 + "\nSynoptic won't be available"
             ) % jdwFileName
-            self.error(msg)
-            self.traceback(level=taurus.Info)
-            result = Qt.QMessageBox.critical(
-                self,
-                "Initialization error",
-                "%s\n\n%s" % (msg, repr(e)),
-                Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-            )
-            if result == Qt.QMessageBox.Abort:
-                sys.exit()
+            self._showInitializationError(e, msg)
 
         Qt.qApp.SDM.connectWriter(
             "SelectedInstrument", synoptic, "graphicItemSelected"
@@ -1126,15 +1115,7 @@ class TaurusGui(TaurusMainWindow):
                 raise Exception()
         except Exception as e:
             msg = 'Could not fetch Instrument list from "%s"' % macroservername
-            self.error(msg)
-            result = Qt.QMessageBox.critical(
-                self,
-                "Initialization error",
-                "%s\n\n%s" % (msg, repr(e)),
-                Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-            )
-            if result == Qt.QMessageBox.Abort:
-                sys.exit()
+            self._showInitializationError(e, msg)
             return []
         for i in instruments.values():
             i_name = i.full_name
@@ -1333,16 +1314,7 @@ class TaurusGui(TaurusMainWindow):
                 xmlroot = etree.fromstring(xmlstring)
             except Exception as e:
                 msg = 'Error reading the XML file: "%s"' % xmlfname
-                self.error(msg)
-                self.traceback(level=taurus.Info)
-                result = Qt.QMessageBox.critical(
-                    self,
-                    "Initialization error",
-                    '%s\nReason:"%s"' % (msg, repr(e)),
-                    Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-                )
-                if result == Qt.QMessageBox.Abort:
-                    sys.exit()
+                self._showInitializationError(e, msg)
         return xmlroot
 
     def _loadAppName(self, conf, confname, xmlroot):
@@ -1614,22 +1586,39 @@ class TaurusGui(TaurusMainWindow):
                 w = p.getWidget(sdm=Qt.qApp.SDM, setModel=False)
 
                 for key, value in p.widget_properties.items():
-                    # set additional configuration for the
+                    # set additional configuration for the widget
                     if hasattr(w, key):
                         try:
                             setattr(w, key, value)
                         except Exception as e:
-                            msg = "Cannot set %r.%s=%s" % (w, key, str(value))
-                            self.error(msg)
-                            self.traceback(level=taurus.Info)
-                            result = Qt.QMessageBox.critical(
-                                self,
-                                "Initialization error",
-                                "%s\n\n%r" % (msg, e),
-                                Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
+                            msg = "Cannot set attribute {} on {}.".format(
+                                key, p.classname
                             )
-                            if result == Qt.QMessageBox.Abort:
-                                sys.exit()
+                            self._showInitializationError(e, msg)
+                    else:
+                        self.warning(
+                            "Attribute {} doesn't exist on {}. It will be"
+                            " ignored.".format(key, p.classname)
+                        )
+
+                for key, value in p.widget_qt_properties.items():
+                    # set qt configuration for the widget
+                    if hasattr(w, key):
+                        try:
+                            method = "set{}".format(key[0].upper() + key[1:])
+                            getattr(w, method)(value)
+                        except Exception as e:
+                            msg = (
+                                "Qt property {} exists on {} but "
+                                "is not currently supported by "
+                                "PanelDescription.".format(key, p.classname)
+                            )
+                            self._showInitializationError(e, msg)
+                    else:
+                        self.warning(
+                            "Qt property {} doesn't exist on {}. It will be"
+                            " ignored.".format(key, p.classname)
+                        )
                 # -------------------------------------------------------------
                 # Backwards-compat. Remove when removing  CW map support
                 if self._customWidgetMap and hasattr(w, "setCustomWidgetMap"):
@@ -1667,16 +1656,7 @@ class TaurusGui(TaurusMainWindow):
                 msg = "Cannot create panel %s" % getattr(
                     p, "name", "__Unknown__"
                 )
-                self.error(msg)
-                self.traceback(level=taurus.Info)
-                result = Qt.QMessageBox.critical(
-                    self,
-                    "Initialization error",
-                    "%s\n\n%s" % (msg, repr(e)),
-                    Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-                )
-                if result == Qt.QMessageBox.Abort:
-                    sys.exit()
+                self._showInitializationError(e, msg)
 
     def _loadCustomToolBars(self, conf, xmlroot):
         """
@@ -1722,16 +1702,7 @@ class TaurusGui(TaurusMainWindow):
                 msg = "Cannot add toolbar %s" % getattr(
                     d, "name", "__Unknown__"
                 )
-                self.error(msg)
-                self.traceback(level=taurus.Info)
-                result = Qt.QMessageBox.critical(
-                    self,
-                    "Initialization error",
-                    "%s\n\n%s" % (msg, repr(e)),
-                    Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-                )
-                if result == Qt.QMessageBox.Abort:
-                    sys.exit()
+                self._showInitializationError(e, msg)
 
     def _loadCustomApplets(self, conf, xmlroot):
         """
@@ -1785,16 +1756,7 @@ class TaurusGui(TaurusMainWindow):
                 msg = "Cannot add applet %s" % getattr(
                     d, "name", "__Unknown__"
                 )
-                self.error(msg)
-                self.traceback(level=taurus.Info)
-                result = Qt.QMessageBox.critical(
-                    self,
-                    "Initialization error",
-                    "%s\n\n%s" % (msg, repr(e)),
-                    Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
-                )
-                if result == Qt.QMessageBox.Abort:
-                    sys.exit()
+                self._showInitializationError(e, msg)
 
     def _loadExternalApps(self, conf, xmlroot):
         """
@@ -1844,6 +1806,18 @@ class TaurusGui(TaurusMainWindow):
             pass
         self.loadSettings(factorySettingsFileName=ini_file_name)
 
+    def _showInitializationError(self, error, msg):
+        self.error(msg)
+        self.traceback(level=taurus.Info)
+        result = Qt.QMessageBox.critical(
+            self,
+            "Initialization error",
+            "{}\n\n{}".format(msg, repr(error)),
+            Qt.QMessageBox.Abort | Qt.QMessageBox.Ignore,
+        )
+        if result == Qt.QMessageBox.Abort:
+            sys.exit()
+
     def setLockView(self, locked):
         self.setModifiableByUser(not locked)
 
@@ -2060,7 +2034,6 @@ class TaurusGui(TaurusMainWindow):
         self.setFocusToPanel("Manual")
 
     def onExportCurrentPanelConfiguration(self, fname=None):
-
         if fname is None:
             fname = self._xmlConfigFileName
 
@@ -2197,6 +2170,42 @@ class TaurusGui(TaurusMainWindow):
         self.info(nfo)
 
 
+@click.command("loadui")
+@click.argument("uiname", nargs=1, required=True)
+def ui_cmd(uiname):
+    """Launch a TaurusApplication opening given .ui file"""
+    import sys
+    import taurus
+    from taurus.external.qt import uic
+    from taurus.qt.qtgui.application import TaurusApplication
+
+    tree = etree.parse(uiname)
+    root = tree.getroot()
+    root_class = root[1].attrib["class"]
+
+    taurus.info("Starting execution of TaurusApplication")
+    app = TaurusApplication(cmd_line_parser=None, app_name="taurusgui")
+
+    if root_class == "QMainWindow":
+        gui = TaurusMainWindow()
+    elif root_class in ["QWidget", "TaurusWidget"]:
+        gui = TaurusWidget()
+    else:
+        taurus.error(
+            "Unrecognized widget type: {}. It should be QMainWindow, "
+            "QWidget or TaurusWidget.".format(root_class)
+        )
+        sys.exit(1)
+
+    app.ui = uic.loadUi(uiname, baseinstance=gui)
+
+    gui.show()
+    ret = app.exec_()
+
+    taurus.info("Finished execution of TaurusApplication")
+    sys.exit(ret)
+
+
 @click.command("gui")
 @click.argument("confname", nargs=1, required=True)
 @click.option(
