@@ -18,4 +18,6 @@ def test_paneldescription(qtbot):
     assert w1.withButtons is False
     assert w1.isWithButtons() is False
     assert not hasattr(w1, "foobar")
+    assert w1.toolTip() == "test tooltip"
+    assert not hasattr(w1, "qt_foobar")
     assert w1.modifiableByUser is False
