@@ -448,6 +448,9 @@ class PanelDescription(TaurusGuiComponentDescription):
         :param widget_properties: a dictionary of property_names:values to be
             set on the widget
         :type widget_properties: dict
+        :param widget_qt_properties: a dictionary of qt_property_names:values
+            to be set on the widget
+        :type widget_qt_properties: dict
         """
         self.instrumentkey = kwargs.pop("instrumentkey", None)
         self.icon = kwargs.pop("icon", None)
@@ -455,6 +458,7 @@ class PanelDescription(TaurusGuiComponentDescription):
         self.modifiable_by_user = kwargs.pop("modifiable_by_user", None)
         self.widget_formatter = kwargs.pop("widget_formatter", None)
         self.widget_properties = kwargs.pop("widget_properties", {})
+        self.widget_qt_properties = kwargs.pop("widget_qt_properties", {})
         TaurusGuiComponentDescription.__init__(self, *args, **kwargs)
 
     @staticmethod
@@ -501,6 +505,7 @@ class PanelDescription(TaurusGuiComponentDescription):
             modifiable_by_user=getattr(panel, "modifiable_by_user", None),
             widget_formatter=getattr(panel, "widget_formatter", None),
             widget_properties=getattr(panel, "widget_properties", {}),
+            widget_qt_properties=getattr(panel, "widget_qt_properties", {}),
         )
 
 
